@@ -18,28 +18,27 @@
 */
 
 #include "mainview.h"
+#include "ai.h"
+#include "options.h"
 
-#include <math.h>
+#include <KActionCollection>
+#include <KConfigGroup>
+#include <KLocalizedString>
+#include <KSharedConfig>
+#include <KToggleAction>
 
 #include <QAbstractEventDispatcher>
 #include <QBrush>
+#include <QFontDatabase>
 #include <QGraphicsSimpleTextItem>
 #include <QKeyEvent>
+#include <QKeySequence>
 #include <QResizeEvent>
+#include <QSvgRenderer>
+#include <QStandardPaths>
 #include <QTimerEvent>
 
-#include <kaction.h>
-#include <kactioncollection.h>
-#include <kglobalsettings.h>
-#include <klocale.h>
-#include <kstandarddirs.h>
-#include <ktoggleaction.h>
-#include <kconfiggroup.h>
-
-#include <QSvgRenderer>
-
-#include "ai.h"
-#include "options.h"
+#include <math.h>
 
 KToggleAction *MyMainView::pauseAction = 0;
 
@@ -65,7 +64,7 @@ MyMainView::MyMainView(QWidget *parent)
    int i,p;
    setMinimumSize(600,400);
    random.setSeed(0);
-   QPixmap backgr(KStandardDirs::locate("appdata",QLatin1String( MV_BACKGROUND) ));
+   QPixmap backgr(QStandardPaths::locate(QStandardPaths::DataLocation, QLatin1String(MV_BACKGROUND)));
 
    field.setBackgroundBrush(QBrush(backgr));
    view.setCacheMode(QGraphicsView::CacheBackground);
@@ -85,7 +84,7 @@ MyMainView::MyMainView(QWidget *parent)
       minePut[p]=false;
    }
 
-   svgrender = new QSvgRenderer(KStandardDirs::locate("appdata",QLatin1String(  MV_SVG_FILE )));
+   svgrender = new QSvgRenderer(QStandardPaths::locate(QStandardPaths::DataLocation, QLatin1String(MV_SVG_FILE)));
 
    sun=new SunSprite(svgrender,QLatin1String( MV_SUN ));
    field.addItem(sun);
@@ -176,7 +175,7 @@ bool MyMainView::readSprites()
 
 void MyMainView::readConfig()
 {
-   KConfigGroup game(KGlobal::config(), "Game");
+   KConfigGroup game(KSharedConfig::openConfig(), "Game");
    int i;
 
    customConfig.gamespeed=game.readEntry("gamespeed",
@@ -250,7 +249,7 @@ void MyMainView::readConfig()
 
 void MyMainView::writeConfig()
 {
-   KConfigGroup game(KGlobal::config(), "Game");
+   KConfigGroup game(KSharedConfig::openConfig(), "Game");
 
    game.writeEntry("gravity",customConfig.gravity);
    game.writeEntry("acceleration",customConfig.acc);
@@ -522,7 +521,7 @@ void MyMainView::newRound()
    //field.update();
 
    QString str = i18n("Press %1 to start",
-                  KShortcut(GAME_START_SHORTCUT).primary().toString(QKeySequence::NativeText));
+                  actionCollection->action("game_start")->shortcut().toString(QKeySequence::NativeText));
    emit(setStatusText(str,IDS_MAIN));
    emit(setStatusText( QLatin1String( "" ), IDS_PAUSE ));
    stop( );
@@ -560,11 +559,12 @@ void MyMainView::timerEvent(QTimerEvent *event)
                delete textSprite;
                textSprite=0;
             }
-            textSprite=new QGraphicsSimpleTextItem(0,&field);
+            textSprite=new QGraphicsSimpleTextItem(0);
+            field.addItem(textSprite);
 	    // FIXME
            // textSprite->setTextFlags(Qt::AlignCenter);
 	    textSprite->setBrush(QBrush(QColor(255,160,0)));
-            textSprite->setFont(QFont(KGlobalSettings::generalFont().family(),14));
+            textSprite->setFont(QFont(QFontDatabase::systemFont(QFontDatabase::GeneralFont).family(),14));
             textSprite->show( );
             if(ship[0]->getHitPoints()==0)
             {
@@ -589,7 +589,7 @@ void MyMainView::timerEvent(QTimerEvent *event)
             textSprite->setPos(QPointF((width()-textSprite->boundingRect().width()) / 2,height()/2-90));
 
             QString str = i18n("Press %1 for new round",
-                           KShortcut(GAME_START_SHORTCUT).primary().toString(QKeySequence::NativeText));
+                          actionCollection->action("game_start")->shortcut().toString(QKeySequence::NativeText));
             emit(setStatusText(str,IDS_MAIN));
             stop( );
          }
@@ -1068,7 +1068,7 @@ void MyMainView::gameSetup()
     return;
 
   SettingsDialog *settings=new SettingsDialog(&customConfig,this,"settings");
-  connect(settings, SIGNAL(settingsUpdated()),this,SLOT(closeSettings()));
+  connect(settings, &SettingsDialog::settingsUpdated, this, &MyMainView::closeSettings);
   settings->show();
 }
 
@@ -1086,4 +1086,4 @@ void MyMainView::focusOutEvent (QFocusEvent * /*event*/)
    setFocus(Qt::OtherFocusReason);
 }
 
-#include "mainview.moc"
+
